VirtualAddress

Struct VirtualAddress 

#[repr(transparent)]
pub struct VirtualAddress { pub addr: usize, }
A virtual memory address

Fields

addr: usize

The underlying address

Implementations

Source

impl VirtualAddress

pub const fn is_higher_half(self) -> bool

Returns true if the VirtualAddress is in the upper half of the address space, i.e. kernelspace

pub const fn new(addr: usize) -> Self

Creates a new VirtualAddress

pub const fn as_ptr(self) -> *mut u8

Converts a VirtualAddress into a raw pointer

pub const fn align_down_to_page(self) -> RawPage

Returns the closest RawPage at or below the current address

pub const fn align_up_to_page(self) -> RawPage

Returns the closest RawPage at or above the current address

pub const fn aligned_to(self, align: usize) -> bool

Returns true if the PhysicalAddress is aligned to align

Panics

If align is not a power of two

pub const fn saturating_add(self, rhs: usize) -> Self

Computed self + rhs saturating when the VirtualAddress reaches [usize::MAX]

pub const fn saturating_sub(self, rhs: usize) -> Self

Computed self - rhs saturating when the VirtualAddress reaches 0

pub const fn to_physical(self) -> PhysicalAddress

Converts an VirtualAddress in the physical page map region into an PhysicalAddress

Panics

Panics if the address is not in the physical page map region on a best effort basis