#[repr(transparent)]pub struct VirtualAddress {
pub addr: usize,
}Expand description
A virtual memory address
Fields
addr: usizeThe underlying address
Implementations
Sourceimpl VirtualAddress
impl VirtualAddress
Sourcepub const fn is_higher_half(self) -> bool
pub const fn is_higher_half(self) -> bool
Returns true if the VirtualAddress is in the upper half of the address space, i.e. kernelspace
Sourcepub const fn new(addr: usize) -> Self
pub const fn new(addr: usize) -> Self
Creates a new VirtualAddress
Sourcepub const fn as_ptr(self) -> *mut u8
pub const fn as_ptr(self) -> *mut u8
Converts a VirtualAddress into a raw pointer
Sourcepub const fn align_down_to_page(self) -> RawPage
pub const fn align_down_to_page(self) -> RawPage
Returns the closest RawPage at or below the current address
Sourcepub const fn align_up_to_page(self) -> RawPage
pub const fn align_up_to_page(self) -> RawPage
Returns the closest RawPage at or above the current address
Sourcepub const fn aligned_to(self, align: usize) -> bool
pub const fn aligned_to(self, align: usize) -> bool
Sourcepub const fn saturating_add(self, rhs: usize) -> Self
pub const fn saturating_add(self, rhs: usize) -> Self
Computed self + rhs saturating when the VirtualAddress reaches [usize::MAX]
Sourcepub const fn saturating_sub(self, rhs: usize) -> Self
pub const fn saturating_sub(self, rhs: usize) -> Self
Computed self - rhs saturating when the VirtualAddress reaches 0
Sourcepub const fn to_physical(self) -> PhysicalAddress
pub const fn to_physical(self) -> PhysicalAddress
Converts an VirtualAddress in the physical page map region into an PhysicalAddress
Panics
Panics if the address is not in the physical page map region on a best effort basis